@@ -3,7 +3,7 @@
 
 ##############################################################
 ##   smscon-editor  -  Configuration UI for the SMSCON      ##
-# $Id: smsconEditorMain.py 130 2011-12-29 22:26:21Z saturn $
+# $Id: smsconEditorMain.py 132 2011-12-30 14:56:06Z saturn $
 ##############################################################
 # Copyright (c) 2010-2011 Christos Zamantzas
 # Licenced under GPLv2
@@ -22,7 +22,7 @@
 ## GNU General Public License for more details.
 ##
 
-Version = '0.9.9-1'
+Version = '0.9.10-1'
 
 import os
 import sys
@@ -351,17 +351,12 @@ class smsconEditorMainWindow(QtGui.QMainWindow):
        ##Set values in the GUI.
        self.SetSystemValues()
 
-    def closeEvent(self, event):
-       """Cleanup on close."""
+    ##Not needed to restart since SMSCON 0.9.10. 
+    ##Code is left here for future use: delete logs when closing the editor?        
+    # def closeEvent(self, event): 
+       # """Cleanup on close."""
 
-       event.accept()
-
-       DAEMONSTATE = os.popen('sudo smscon -status').read().strip('\n') 
-       if DAEMONSTATE.endswith('running'):
-          if self.isSmsconTestActive:
-             message = 'Test mode was active.\nSwitching to normal operation...'
-             showQuickMessage(message)
-          self.doRestart();
+       # event.accept()
 
     def SetSystemValues(self):
        '''Set GUI values from the current operation'''
@@ -548,10 +543,9 @@ class smsconEditorGeneral(QtGui.QMainWindow):  ## General Settings
        
     def closeEvent(self, event):
        """Store settings on close."""
-       event.accept()
 
+       event.accept()
        self.doCreateConfigGeneral()
-       # self.doRestart();
         
     def doCreateConfigGeneral(self):
 
@@ -609,10 +603,9 @@ class smsconEditorEmail(QtGui.QMainWindow):    ## Email Settings
 
     def closeEvent(self, event):
        """Store settings on close."""
-       event.accept()
 
+       event.accept()
        self.doCreateConfigEmail()
-       # self.doRestart();
        
     def doCreateConfigEmail(self):
 
@@ -704,10 +697,9 @@ class smsconEditorCommands(QtGui.QMainWindow): ## Commands Renaming
 
     def closeEvent(self, event):
        """Store settings on close."""
-       event.accept()
 
+       event.accept()
        self.doCreateConfigCommands()
-       # self.doRestart();
        
     def doCreateConfigCommands(self):
 
@@ -766,10 +758,9 @@ class smsconEditorSSH(QtGui.QMainWindow):      ## SSH Settings
 
     def closeEvent(self, event):
        """Store settings on close."""
-       event.accept()
 
+       event.accept()
        self.doCreateConfigSSH()
-       # self.doRestart();
        
     def doCreateConfigSSH(self):
 
@@ -814,10 +805,9 @@ class smsconEditorHost(QtGui.QMainWindow):     ## Host Settings
 
     def closeEvent(self, event):
        """Store settings on close."""
-       event.accept()
 
+       event.accept()
        self.doCreateConfigHOST()
-       # self.doRestart();
        
     def doCreateConfigHOST(self):
 
